@@ -418,9 +418,7 @@ def create_manifest(collection_id, object_id, config_path="~/.iiiflow.yml"):
 
         obj_url_root = f"{manifest_url_root}/{collection_id}/{object_id}"
         # image_api_root has been normalized to always include trailing slash (/) or %2F for subfolders after the IIIF image api
-        print (image_api_root)
         iiif_url_root = f"{image_api_root}{collection_id}%2F{object_id}%2F{resource_format}"
-        print (iiif_url_root)
         if "title" in metadata.keys():
             manifest_label = metadata['title'].strip()
             if "date_display" in metadata.keys():
